OiRA

Help

1. Paruošimas
2. Įtraukti
3. Nustatymas + Vertinimas
4. Veiksmų planas
5. Ataskaita
6. Būsena 0%

# Atsisiųskite ir atsispausdinkite savo ataskaitą

Rekomenduojame visada turėti aktualią spausdintinę rizikos vertinimo (ataskaitos) versiją, su kuria būtų galima susipažinti jūsų įmonėje!

Ataskaita

- Format: Rich Text Format (.rtf)
- Contains: all the information and input provided by you throughout the risk assessment process.

Veiksmų planas

- Format: Office Open XML Workbook (.xlsx)
- Contains: main elements to effectively manage the risks at your workplace.

Rizikų peržiūra

- Format: Portable Document Format (.pdf)
- Contains: an overview of the risks identified

Priemonių peržiūra

- Format: Portable Document Format (.pdf)
- Contains: an overview of the measures to be implemented.

Scroll to top
Back

## report-download.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More